@@ -7,18 +7,18 @@ elements_score = [random.randint(1, 20) for _ in range(30)]
 
 
 # evaluator example
-def evaluatorExample(_solution):
+def evaluatorExample(solution):
     """
     Evaluator's example of solution to compute fitness
 
     Args:
-        _solution: {Solution} -- solution to evaluate
+        solution: {Solution} -- solution to evaluate
 
     Returns:
         {float} -- fitness score of solution
     """
     fitness = 0
-    for index, elem in enumerate(_solution.data):
+    for index, elem in enumerate(solution.data):
         fitness += elements_score[index] * elem
 
     return fitness
